@@ -2,6 +2,7 @@ from pprint import pprint
 import ast
 
 import numpy as np
+import pandas as pd
 from math import fabs
 import networkx as nx
 from grid2op.dtypes import dt_int
@@ -37,7 +38,7 @@ class Grid2opSimulation(Simulation):
     def get_layout(self):
         return self.layout
 
-    def __init__(self, obs, env, param_options=None, debug = False, ltc=[9],other_ltc=[], plot=False, plot_folder = None,reward_type=None):
+    def __init__(self, obs, action_space, observation_space, param_options=None, debug = False, ltc=[9],other_ltc=[], plot=False, plot_folder = None,reward_type=None):
         super().__init__()
 
         # Get Grid2op objects
@@ -48,9 +49,9 @@ class Grid2opSimulation(Simulation):
             self.printer = Printer(plot_folder)
         self.obs = obs
         self.obs_linecut = None
-        self.action_space = env.action_space
-        self.observation_space = env.observation_space
-        self.env=env
+        self.action_space = action_space#env.action_space
+        self.observation_space = observation_space#env.observation_space
+        #self.env=env
         self.plot_helper = self.get_plot_helper()
         self.no_overflow_disc = self.obs._obs_env.no_overflow_disconnection # Keep it in memory to activate and deactivate during computation steps
 
@@ -213,8 +214,9 @@ class Grid2opSimulation(Simulation):
 
                 score_data=self.compute_one_network_change_score_data(obs,virtual_obs,done,info,new_conf,internal_target_node,alphaDeesp_Internal_topo,new_conf_grid2op,score_topo)
                 #print(score_data)
-                max_index = end_result_dataframe.shape[0]  # rows
-                end_result_dataframe.loc[max_index] = score_data
+                #max_index = end_result_dataframe.shape[0]  # rows
+                #end_result_dataframe.loc[max_index] = score_data
+                end_result_dataframe=end_result_dataframe.append(pd.Series(score_data, index=end_result_dataframe.columns ),ignore_index=True)
                 ii += 1
                 j += 1
 
